pub struct GlobalAccountData {
session: OnceCell<Session>,
pub(super) media_previews_enabled: RefCell<MediaPreviews>,
invite_avatars_enabled: Cell<bool>,
abort_handle: RefCell<Option<AbortHandle>>,
}Fields
session: OnceCell<Session>The session this account data belongs to.
media_previews_enabled: RefCell<MediaPreviews>Which rooms display media previews for this session.
invite_avatars_enabled: Cell<bool>Whether to display avatars in invites.
abort_handle: RefCell<Option<AbortHandle>>Implementations
Sourceimpl GlobalAccountData
impl GlobalAccountData
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl GlobalAccountData
impl GlobalAccountData
Sourcepub(super) async fn init_media_previews_settings(&self)
pub(super) async fn init_media_previews_settings(&self)
Initialize the media previews settings from the account data and watch for changes.
Sourcefn update_media_previews_settings(
&self,
account_data: MediaPreviewConfigEventContent,
)
fn update_media_previews_settings( &self, account_data: MediaPreviewConfigEventContent, )
Update the media previews settings with the given account data.
Sourcepub(super) async fn apply_migrations(&self)
pub(super) async fn apply_migrations(&self)
Apply any necessary migrations.
Sourcepub(super) async fn set_media_previews_enabled(
&self,
setting: MediaPreviews,
) -> Result<(), ()>
pub(super) async fn set_media_previews_enabled( &self, setting: MediaPreviews, ) -> Result<(), ()>
Set which rooms display media previews.